pub struct WindowedInfinity<'a> { /* private fields */ }Expand description
A WindowedInfinity represents an infinite writable space. A small section of it is mapped to a &mut u8 to which writes are forwarded; writes to the area outside only advance a cursor.
Implementations
Sourceimpl<'a> WindowedInfinity<'a>
impl<'a> WindowedInfinity<'a>
Sourcepub fn new(view: &'a mut [u8], cursor: isize) -> Self
pub fn new(view: &'a mut [u8], cursor: isize) -> Self
Create a new infinity with the window passed as view. The cursor parameter indicates where (in the index space of the view) the infinity’s write operations should start, and is typically either 0 or negative.
Sourcepub fn cursor(&self) -> isize
pub fn cursor(&self) -> isize
Report the current write cursor position in the index space of the view.
This typically used at the end of an infinity’s life time to see whether the view needs to be truncated before further processing, and whether there was any data discarded after the view.