pub struct WindowedInfinity<'a> { /* private fields */ }
A WindowedInfinity represents an infinite writable space. A small section of it is mapped to a &mut u8 to which writes are forwarded; writes to the area outside only advance a cursor.

The set of traits it implements depends on the configured cargo features:

  • With the std feature, it implements std::io::Write
  • With the with_serde_cbor feature, it uses serde_cbor’s trait unsealing feature to implement its Write trait.

Implementations

Create a new infinity with the window passed as view. The cursor parameter indicates where (in the index space of the view) the infinity’s write operations should start, and is typically either 0 or negative.

Report the current write cursor position in the index space of the view.

This typically used at the end of an infinity’s life time to see whether the view needs to be truncated before further processing, and whether there was any data discarded after the view.

At the current cursor position, insert the given data.

The operation is always successful, and at least changes the write cursor.

Obtain the written content inside the window, if any.

The slices could be made to have a longer lifetime if there is demand for that by using the sealingslice crate.